// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef EVENTVIEWS_VERSION_H
#define EVENTVIEWS_VERSION_H

#define EVENTVIEWS_VERSION_STRING "5.23.2"
#define EVENTVIEWS_VERSION_MAJOR 5
#define EVENTVIEWS_VERSION_MINOR 23
#define EVENTVIEWS_VERSION_PATCH 2
#define EVENTVIEWS_VERSION ((5<<16)|(23<<8)|(2))

#endif
